@@ -1,13 +1,12 @@
 from livestreamer.compat import str
-from livestreamer.plugins import Plugin, PluginError, NoStreamsError, register_plugin
+from livestreamer.plugins import Plugin, PluginError, NoStreamsError
 from livestreamer.stream import RTMPStream
 from livestreamer.utils import urlget, swfverify, verifyjson
 
-import json, re
-
+import re
 
 class SVTPlay(Plugin):
-    JSONURL = "http://svtplay.se/live/{0}?output=json"
+    JSONURL = "http://svtplay.se/live/{0}"
     SWFURL = "http://www.svtplay.se/public/swf/video/svtplayer-2012.15.swf"
     PageURL = "http://www.svtplay.se"
 
@@ -18,9 +17,10 @@ class SVTPlay(Plugin):
     def _get_channel_id(self, url):
         self.logger.debug("Fetching channel id")
 
-        data = urlget(url)
+        res = urlget(url)
 
-        match = re.search(b'data-json-href="/live/(\d+)"', data)
+
+        match = re.search('data-json-href="/live/(\d+)"', res.text)
         if match:
             return int(match.group(1))
 
@@ -31,15 +31,13 @@ class SVTPlay(Plugin):
             raise NoStreamsError(self.url)
 
         self.logger.debug("Fetching stream info")
-        data = urlget(self.JSONURL.format(channelid))
+        res = urlget(self.JSONURL.format(channelid), params=dict(output="json"))
 
-        try:
-            info = json.loads(str(data, "utf8"))
-        except ValueError as err:
-            raise PluginError(("Unable to parse JSON: {0})").format(err))
+        if res.json is None:
+            raise PluginError("No JSON data in stream info")
 
         streams = {}
-        video = verifyjson(info, "video")
+        video = verifyjson(res.json, "video")
         videos = verifyjson(video, "videoReferences")
 
         self.logger.debug("Verifying SWF: {0}", self.SWFURL)
@@ -49,7 +47,7 @@ class SVTPlay(Plugin):
             if not ("url" in video and "playerType" in video and video["playerType"] == "flash"):
                 continue
 
-            stream = RTMPStream({
+            stream = RTMPStream(self.session, {
                 "rtmp": video["url"],
                 "pageUrl": self.PageURL,
                 "swfhash": swfhash,
@@ -58,7 +56,6 @@ class SVTPlay(Plugin):
             })
             streams[str(video["bitrate"]) + "k"] = stream
 
-
         return streams
 
-register_plugin("svtplay", SVTPlay)
+__plugin__ = SVTPlay
