@@ -1,5 +1,5 @@
 from livestreamer.compat import str, bytes
-from livestreamer.plugins import Plugin, PluginError, NoStreamsError, register_plugin
+from livestreamer.plugins import Plugin, PluginError, NoStreamsError
 from livestreamer.stream import RTMPStream
 from livestreamer.utils import urlget
 
@@ -14,9 +14,9 @@ class UStreamTV(Plugin):
         return "ustream.tv" in url
 
     def _get_channel_id(self, url):
-        data = urlget(url)
+        res = urlget(url)
 
-        match = re.search(b"channelId=(\d+)", data)
+        match = re.search("channelId=(\d+)", res.text)
         if match:
             return int(match.group(1))
 
@@ -34,14 +34,15 @@ class UStreamTV(Plugin):
             raise NoStreamsError(self.url)
 
         self.logger.debug("Fetching stream info")
-        data = urlget(self.AMFURL.format(channelid))
+        res = urlget(self.AMFURL.format(channelid))
+        data = res.content
 
         playpath = get_amf_value(data, "streamName")
         cdnurl = get_amf_value(data, "cdnUrl")
         fmsurl = get_amf_value(data, "fmsUrl")
 
         if playpath:
-            stream = RTMPStream({
+            stream = RTMPStream(self.session, {
                 "rtmp": ("{0}/{1}").format(cdnurl or fmsurl, playpath),
                 "pageUrl": self.url,
                 "swfUrl": self.SWFURL,
@@ -51,4 +52,4 @@ class UStreamTV(Plugin):
 
         return streams
 
-register_plugin("ustreamtv", UStreamTV)
+__plugin__ = UStreamTV
