@@ -1,6 +1,5 @@
-from . import options
-from .utils import urlopen
 from .compat import str, is_win32
+from .utils import urlget
 
 import os
 import pbs
@@ -11,15 +10,30 @@ class StreamError(Exception):
     pass
 
 class Stream(object):
+    """
+        This is a base class that should be inherited when implementing
+        different stream types. Should only be used directly from plugins.
+    """
+
+    def __init__(self, session):
+        self.session = session
+
     def open(self):
-       raise NotImplementedError
+        """
+            Opens a connection to the stream.
+            Returns a file-like object than can be used to read data.
+            Raises :exc:`StreamError` on failure.
+        """
+        raise NotImplementedError
 
 class StreamProcess(Stream):
-    def __init__(self, params):
-        self.params = params or {}
+    def __init__(self, session, params={}):
+        Stream.__init__(self, session)
+
+        self.params = params
         self.params["_bg"] = True
         self.params["_err"] = open(os.devnull, "w")
-        self.errorlog = options.get("errorlog")
+        self.errorlog = self.session.options.get("errorlog")
 
     def cmdline(self):
         return str(self.cmd.bake(**self.params))
@@ -45,10 +59,10 @@ class StreamProcess(Stream):
         return stream.process.stdout
 
 class RTMPStream(StreamProcess):
-    def __init__(self, params):
-        StreamProcess.__init__(self, params)
+    def __init__(self, session, params):
+        StreamProcess.__init__(self, session, params)
 
-        self.rtmpdump = options.get("rtmpdump") or (is_win32 and "rtmpdump.exe" or "rtmpdump")
+        self.rtmpdump = self.session.options.get("rtmpdump") or (is_win32 and "rtmpdump.exe" or "rtmpdump")
         self.params["flv"] = "-"
 
         try:
@@ -75,11 +89,17 @@ class RTMPStream(StreamProcess):
         return False
 
 class HTTPStream(Stream):
-    def __init__(self, url):
+    def __init__(self, session, url, **args):
+        Stream.__init__(self, session)
+
         self.url = url
+        self.args = args
 
     def open(self):
-        return urlopen(self.url)
+        res = urlget(self.url, prefetch=False,
+                     exception=StreamError,
+                     **self.args)
 
+        return res.raw
 
 __all__ = ["StreamError", "Stream", "StreamProcess", "RTMPStream", "HTTPStream"]
